@@ -10,7 +10,7 @@ from nonebot.matcher import Matcher
 from nonebot.exception import ParserExit
 from nonebot.plugin import PluginMetadata
 from nonebot.rule import Rule, ArgumentParser
-from nonebot import on_command, on_shell_command, on_message
+from nonebot import on_command, on_shell_command, on_message, require
 from nonebot.params import (
     ShellCommandArgv,
     Command,
@@ -22,6 +22,8 @@ from nonebot.params import (
 from nonebot.adapters.onebot.v11 import MessageSegment as MS
 from nonebot.adapters.onebot.v11 import MessageEvent, GroupMessageEvent, Message
 
+require("nonebot_plugin_datastore")
+
 from .move import Move
 from .config import Config
 from .board import MoveResult
@@ -42,7 +44,7 @@ __plugin_meta__ = PluginMetadata(
         "unique_name": "cchess",
         "example": "@小Q 象棋人机lv5\n炮二平五\n结束下棋",
         "author": "meetwq <meetwq@gmail.com>",
-        "version": "0.1.6",
+        "version": "0.1.8",
     },
 )
 
